@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: disparea.h,v 1.1 2005/05/08 22:09:43 jeremy_laine Exp $
+ * $Id: disparea.h,v 1.2 2005/09/03 14:28:58 jeremy_laine Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -42,7 +42,10 @@ protected:
     CPoint3d center;
 
     /** The zoom factor for the view */
-    real zoom;  
+    real zoom;
+    
+    /** Has the area been resized since last redraw */
+    bool wasResized;
 };
 
 
