@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
  *
- * $Id: formdef.cpp,v 1.69 2005/05/08 20:29:20 sailcuter Exp $
+ * $Id: formdef.cpp,v 1.75 2005/10/23 17:53:57 sailcuter Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,11 @@
  */
 
 #include "formdef.h"
-#include <qlabel.h>
-#include <qradiobutton.h>
-#include <qlineedit.h>
+#include <QLabel>
+#include <QMessageBox>
+#include <QRadioButton>
+#include <QLineEdit>
+#include "sailworker.h"
 
 //////////////////////////////////////////////////////////////////////
 // Construction/Destruction
@@ -34,13 +36,15 @@
  * @param sailptr pointer to the CSailDef
  */
 CFormDef::CFormDef( QWidget* parent, CSailDef * sailptr )
-        : CFormDefBase(parent, 0, true)
+        : QDialog(parent)
 {
+    setupUi(this);
+    setModal(true);
+
     /* we store the pointer to the CSailDef so we can update it when
        the user clicks OK */
     saildef = sailptr;
 
-
     setSailCut( saildef->sailCut );
     setSailType( saildef->sailType );
 
@@ -89,15 +93,40 @@ CFormDef::CFormDef( QWidget* parent, CSailDef * sailptr )
 
     // radioRadial->setEnabled(false);
 
+    // create button group for sail type
+    QButtonGroup *bgrpSailType = new QButtonGroup( this );
+    bgrpSailType->addButton( radioMainSail );
+    bgrpSailType->addButton( radioJib );
+    bgrpSailType->addButton( radioWing );
+
+    // create button group for sail cut
+    QButtonGroup *bgrpSailCut = new QButtonGroup( this );
+    bgrpSailCut->addButton( radioCross );
+    bgrpSailCut->addButton( radioTwist );
+    bgrpSailCut->addButton( radioHorizontal );
+    bgrpSailCut->addButton( radioVertical );
+    bgrpSailCut->addButton( radioMitre );
+    bgrpSailCut->addButton( radioRadial );
+
+    // signals and slots connections
+    connect( btnOK, SIGNAL( clicked() ), this, SLOT( accept() ) );
+    connect( btnCancel, SIGNAL( clicked() ), this, SLOT( reject() ) );
+    connect( btnCompute, SIGNAL( pressed() ), this, SLOT( slotCompute() ) );
+    connect( bgrpSailType, SIGNAL( buttonClicked(QAbstractButton *) ), this, SLOT( slotSailType() ) );
+    connect( bgrpSailCut, SIGNAL( buttonClicked(QAbstractButton *) ), this, SLOT( slotSailCut() ) );
+
     // calculate sail area and diagonal and display it
     compute();
 }
 
 
+/** The destructor.
+ */
 CFormDef::~CFormDef()
 {}
 
 
+
 // member functions
 
 /** Compute and Display ancillary data of the sail computation*/
@@ -106,7 +135,6 @@ void CFormDef::compute()
     CSailWorker worker(*saildef);
     lblSailArea->setText ( QString::number( worker.Area() ) );
     lblDiagonal->setText ( QString::number( worker.Diagonal() ) );
-
 }
 
 
@@ -147,7 +175,6 @@ enumSailType CFormDef::getSailType()
  */
 void CFormDef::setSailCut( enumSailCut cut )
 {
-
     switch ( cut )
     {
     case CROSS:
@@ -201,7 +228,7 @@ void CFormDef::setSailType( enumSailType type )
         radioTwist->setEnabled( true );
         radioVertical->setEnabled( true );
         radioMitre->setEnabled( true );
-         break;
+        break;
 
     case JIB:
         //qDebug("setSailType( JIB )");
@@ -265,7 +292,7 @@ void CFormDef::accept()
 {
     // return data if everything is OK. /////////////////////////
     if (check() ==true)
-        CFormDefBase::accept();
+        QDialog::accept();
 }
 
 
@@ -278,21 +305,21 @@ bool CFormDef::check()
     real A1=0, A2=0;
     bool flag=true;
     QString txt;
-    // create four palettes
+    ///  create four palettes
     QPalette palStd, palHi, palLo, palRel;
     palStd = txtLuffLen->palette();
     palLo = palHi = palRel = palStd;
-    palLo.setColor( QColorGroup::Text, Qt::magenta); // too low value
-    palHi.setColor( QColorGroup::Text, Qt::red );    // too high value
-    palRel.setColor( QColorGroup::Text, Qt::blue );  // related value to be checked
+    palLo.setColor( QPalette::Text, Qt::magenta); // too low value
+    palHi.setColor( QPalette::Text, Qt::red );    // too high value
+    palRel.setColor( QPalette::Text, Qt::blue );  // related value to be checked
 
-    //// start collecting data
+    ///  start collecting data
     saildef->sailCut = getSailCut();
     saildef->sailType = getSailType();
     txt = txtSailID->text();
-    txt = txt.simplifyWhiteSpace();
+    txt = txt.simplified();
 
-    //// check the sail ID text
+    ///  check the sail ID text
     if (txt.length() > 40)
     {
         txt.truncate(40);
@@ -307,7 +334,7 @@ bool CFormDef::check()
     }
     saildef->sailID = txt;
 
-    //// check length of boat and fore triangle wrt length of boat
+    ///  check length of boat and fore triangle wrt length of boat
     saildef->LOA = txtLOA->text().toDouble();
 
     if (saildef->LOA < 100)
@@ -376,7 +403,7 @@ bool CFormDef::check()
     }
     txtTriangHoist->setText(QString::number(saildef->foreI));
 
-    //// check tack position
+    ///  check tack position
     L1 = (long)(saildef->LOA);
 
     saildef->tackX  = txtTackDist->text().toDouble();
@@ -412,7 +439,7 @@ bool CFormDef::check()
     }
     txtTackHeight->setText(QString::number(saildef->tackY));
 
-    //// get data on the sides of sail
+    ///  get data on the sides of sail
     saildef->luffL  = txtLuffLen->text().toDouble();
     saildef->luffR  = txtLuffRound->text().toDouble();
     saildef->luffRP = txtLuffRoundPos->text().toInt();
@@ -428,7 +455,7 @@ bool CFormDef::check()
     saildef->footL  = txtFootLen->text().toDouble();
     saildef->footR  = txtFootRound->text().toDouble();
 
-    //// check  rake
+    ///  check  rake
     saildef->rake   = txtRake->text().toDouble();
 
     switch (saildef->sailType )
@@ -479,7 +506,7 @@ bool CFormDef::check()
         break;
     }
 
-    //// check luff length and round, gaff length
+    ///  check luff length and round, gaff length
     L1 = (long)(saildef->LOA);
 
     switch (saildef->sailType )
@@ -616,7 +643,7 @@ bool CFormDef::check()
         }
         txtLuffRound->setText(QString::number(saildef->luffR) );
 
-        // check jib gaff length
+        /// check jib gaff length
         L1 =(long) (1);
         L2 =(long) (70);
 
@@ -645,7 +672,7 @@ bool CFormDef::check()
         break;
 
     case WING:
-        // set gaff to minimum
+        ///  set gaff to minimum
         saildef->gaffL = 2;
         txtGaffLen->setText(QString::number(saildef->gaffL) );
         saildef->gaffR = 0;
@@ -686,7 +713,7 @@ bool CFormDef::check()
         break;
     }
 
-    /// check leech length
+    ///  check leech length
     L1 = (long) saildef->luffL;
     L1 = L1 + (long) saildef->gaffL;
 
@@ -711,7 +738,7 @@ bool CFormDef::check()
     }
     txtLeechLen->setText(QString::number(saildef->leechL));
 
-    /// check leech round
+    ///  check leech round
     L1 = (long) (saildef->leechL / 10);
     if (saildef->leechR > 3*L1)
     {
@@ -728,7 +755,7 @@ bool CFormDef::check()
     else
         txtLeechRound->setPalette(palStd);
 
-    /// check foot length
+    ///  check foot length
     switch (saildef->sailType )
     {
     case MAINSAIL:
@@ -769,7 +796,7 @@ bool CFormDef::check()
     }
     txtFootLen->setText( QString::number( saildef->footL ) );
 
-    /// check foot round
+    ///  check foot round
     L1 = (long)(saildef->footL / 5);
 
     switch (saildef->sailType)
@@ -804,7 +831,7 @@ bool CFormDef::check()
         break;
     }
 
-    /// get and check seams and hems width
+    ///  get and check seams and hems width
     saildef->clothW = txtClothWidth->text().toDouble();
     saildef->seamW  = txtSeamWidth->text().toDouble();
     saildef->leechHemW = txtLeechHemWidth->text().toDouble();
@@ -882,13 +909,13 @@ bool CFormDef::check()
     txtHemsWidth->setText( QString::number(saildef->hemsW));
 
 
-    /// get and check mould
+    ///  get and check mould
     saildef->mould.profile[2].setDepth( real(txtTopDepth->text().toInt())/100 );
     saildef->mould.profile[1].setDepth( real(txtMidDepth->text().toInt())/100 );
     saildef->mould.profile[0].setDepth( real(txtFootDepth->text().toInt())/100 );
 
 
-    /// get and check dihedral angle
+    ///  get and check dihedral angle
     saildef->dihedralDeg = txtDihedral->text().toInt();
     if (saildef->dihedralDeg<90)
     {
@@ -909,7 +936,7 @@ bool CFormDef::check()
     txtDihedral->setText(QString::number(saildef->dihedralDeg));
 
 
-    /// get and check twist
+    ///  get and check twist
     saildef->twistDeg = txtTwistAngle->text().toInt();
     if (saildef->twistDeg > 45)
     {
@@ -930,7 +957,7 @@ bool CFormDef::check()
     txtTwistAngle->setText(QString::number(saildef->twistDeg));
 
 
-    /// get and check sheeting angle
+    ///  get and check sheeting angle
     saildef->sheetDeg = txtSheetAngle->text().toInt();
 
     if (saildef->sheetDeg > 45)
@@ -970,7 +997,7 @@ bool CFormDef::check()
     txtSheetAngle->setText(QString::number(saildef->sheetDeg));
 
 
-    /// get and check radial sections and gores
+    ///  get and check radial sections and gores
     if (saildef->sailCut == RADIAL)
     {
         saildef->nbGores = txtGores->text().toInt();
@@ -988,7 +1015,9 @@ bool CFormDef::check()
             txtGores->setText(QString::number(7));
         }
         else
+        {
             txtGores->setPalette( palStd);
+        }
         saildef->nbGores = txtGores->text().toInt();
 
         saildef->nbSections = txtSections->text().toInt();
@@ -1006,7 +1035,9 @@ bool CFormDef::check()
             txtSections->setText(QString::number(8));
         }
         else
+        {
             txtSections->setPalette( palStd);
+        }
         saildef->nbSections = txtSections->text().toInt();
 
         saildef->nbLuffGores = txtLuffGores->text().toInt();
@@ -1017,18 +1048,20 @@ bool CFormDef::check()
             txtLuffGores->setPalette( palLo);
             txtLuffGores->setText(QString::number(1));
         }
-        else  if (saildef->nbLuffGores > saildef->nbGores -1)
+        else  if (saildef->nbLuffGores > saildef->nbGores -2)
         {
             flag=false;
             txtLuffGores->setPalette( palHi);
-            txtLuffGores->setText(QString::number(saildef->nbGores -1));
+            txtLuffGores->setText(QString::number(saildef->nbGores -2));
         }
         else
+        {
             txtLuffGores->setPalette( palStd);
+        }
         saildef->nbLuffGores = txtLuffGores->text().toInt();
     }
 
-    /// return true IF everything is OK
+    ///  return true IF everything is OK
     return flag;
 }
 
@@ -1060,34 +1093,41 @@ void CFormDef::slotCompute()
 
     CSailWorker worker(*saildef);
 
-    w=worker.SailLP();
-    txtb =  "LP = "+QString::number(w) +" mm";
+    txta = tr("Sail corners coordinates");
+    txta = txta+"\n  "+tr("tack")+" \t x = "+QString::number(int(worker.tack.x())) +"\n\t y = "+QString::number(int(worker.tack.y())) +" mm" ;
+    txta = txta+"\n  "+tr("clew")+" \t x = "+QString::number(int(worker.clew.x())) +"\n\t y = "+QString::number(int(worker.clew.y())) +" mm";
+    txta = txta+"\n  "+tr("head")+" \t x = "+QString::number(int(worker.head.x())) +"\n\t y = "+QString::number(int(worker.head.y())) +" mm";
+    txta = txta+"\n  "+tr("peak")+" \t x = "+QString::number(int(worker.peak.x())) +"\n\t y = "+QString::number(int(worker.peak.y())) +" mm";
 
-   txta = "IRC width measurement";
+    w = worker.SailLP();
+    txtb = "\nLP = " +QString::number(int(w)) +" mm";
+
+   txtc = "\n" + tr("IRC width measurements");
    h=0.5;
-    w= worker.IRCwidth(h);
+    w = worker.IRCwidth(h);
     // printf ("IRC width %f \n", w);
-    txtc = "width at h= "+QString::number(h)+"  w= "+QString::number(w);
+    txtc = txtc +"\n  h= "+QString::number(h)+"\t w= "+QString::number(int(w)) +" mm";
 
     h=0.75;
-    w= worker.IRCwidth(h);
-    txtd =  "width at h= "+QString::number(h)+"  w= "+QString::number(w);
+    w = worker.IRCwidth(h);
+    txtc = txtc+ "\n  h= "+QString::number(h)+"\t w= "+QString::number(int(w)) +" mm";
 
     h=0.875;
-    w= worker.IRCwidth(h);
-    txte =  "width at h= "+QString::number(h)+"  w= "+QString::number(w);
+    w = worker.IRCwidth(h);
+    txtc = txtc  + "\n  h= "+QString::number(h)+"\t w= "+QString::number(int(w)) +" mm";
 
-    displayData(  txtb, txta, txtc, txtd, txte );
+    displayData(  txta, txtb, txtc, txtd, txte );
 
 }
 
+
 /** display data in a message box
  */
 void CFormDef::displayData(QString &txt0, QString &txt1, QString &txt2, QString &txt3, QString &txt4 )
 {
     QMessageBox* mb = new QMessageBox();
-    mb->setIcon(QMessageBox::Information);
-    mb->setCaption(tr("Sailcut"));
+    mb->setIcon(QMessageBox::NoIcon);
+    mb->setWindowTitle("Sailcut");
     mb->setText (QString(txt0+"\n" +txt1+"\n" +txt2+"\n" +txt3+"\n" +txt4));
     mb->setButtonText (0, "OK");
     mb->exec();
