@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: formhelp.h,v 1.6 2004/10/26 19:30:35 jeremy_laine Exp $
+ * $Id: formhelp.h,v 1.7 2005/09/03 14:28:58 jeremy_laine Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ class CFormHelp : public QDialog
     Q_OBJECT
 
 public:
-    CFormHelp(QWidget *parent, CPrefs *pref, const QString& base);
+    CFormHelp(QWidget *parent, CPrefs *pref, const QString& handbook);
     ~CFormHelp();
 
 protected:
