@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
  * 
- * $Id: main.cpp,v 1.14 2004/10/26 19:30:38 jeremy_laine Exp $
+ * $Id: main.cpp,v 1.15 2005/09/03 14:28:58 jeremy_laine Exp $
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -35,13 +35,12 @@ int main( int argc, char* argv[] )
         CSailApp app( argc, argv );
         app.readPrefs();
 
-        CFormMain sailcut(&app);
-        app.setMainWidget( &sailcut );
-
-        if (argc > 1)
-            sailcut.show(argv[1]);
+        CFormMain *sailcut = new CFormMain(&app);
+        
+	if (argc > 1)
+            sailcut->show(argv[1]);
         else
-            sailcut.show();
+            sailcut->show();
 
         retCode = app.exec();
         app.writePrefs();
