@@ -1,32 +1,30 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
- * 
- * $Id: sail.cpp,v 1.53 2004/10/26 19:30:38 jeremy_laine Exp $
- * 
+ *
+ * $Id: sail.cpp,v 1.58 2005/10/02 17:32:14 sailcuter Exp $
+ *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
  * (at your option) any later version.
- * 
+ *
  * This program is distributed in the hope that it will be useful,
  * but WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  * GNU General Public License for more details.
- * 
+ *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  */
 
 #include "sail.h"
-#include "sailcalc.h"
-#include "geocpp/matrix.h"
 
 /*****************************************************************************
- 
+
                               CPanelLabel class
- 
+
 *****************************************************************************/
 
 /** Default constructor */
@@ -95,9 +93,9 @@ CPanelLabel& CPanelLabel::operator= (const CPanelLabel &lb)
 }
 
 /*****************************************************************************
- 
+
                               CPanel class
- 
+
 *****************************************************************************/
 
 /** Default constructor */
@@ -122,10 +120,19 @@ CPanel::CPanel( const CPanel &p )
 CRect3d CPanel::boundingRect() const
 {
     CRect3d rect;
-    const CSide * sarray[4] =
-        {
-            &top,&bottom, &left, &right
-        };
+    const CSide * sarray[4];
+    if (hasHems)
+    {
+        sarray[0]=  &cutTop;
+        sarray[1] = &cutBottom;
+        sarray[2] = &cutLeft;
+        sarray[3] = &cutRight;;
+    } else {
+        sarray[0]=  &top;
+        sarray[1] = &bottom;
+        sarray[2] = &left;
+        sarray[3] = &right;;
+    }
 
     rect.min = rect.max = top.point[0];
 
@@ -185,7 +192,7 @@ CPoint3d CPanel::centroid() const
 
 /** This routine returns the height ( in Y direction ) of a panel
  */
-real CPanel::height()
+real CPanel::height() const
 {
     real h=0;
 
@@ -911,7 +918,7 @@ void CPanel::addHems( const real &lw, const real &tw, const real &rw, const real
 
 
 /** Rotates a panel around a point.
- *  p = centre of rotation 
+ *  p = centre of rotation
  *  m = rotation matrix
  */
 CPanel CPanel::rotate( const CPoint3d &p, const CMatrix &m ) const
@@ -985,9 +992,9 @@ CPanel& CPanel::operator= (const CPanel &p)
 
 
 /*****************************************************************************
- 
+
                               CSail class
- 
+
 *****************************************************************************/
 
 /** Constructs a sail with the specified number of panels.
@@ -1006,6 +1013,7 @@ CSail::CSail( const CSail& s )
 {
     changed = true;
     panel = s.panel;
+    sailID = s.sailID;
 }
 
 
@@ -1111,6 +1119,7 @@ CSail& CSail::operator=(const CSail& s)
         return *this;
 
     panel = s.panel;
+    sailID = s.sailID;
 
     // set 'changed' attribute to true
     changed = true;
@@ -1135,9 +1144,9 @@ CSail CSail::operator+(const CVector3d& transl) const
 
 
 /*****************************************************************************
- 
+
                               CSide class
- 
+
 *****************************************************************************/
 
 /** Constructs a side with a given number of points.
@@ -1247,9 +1256,9 @@ CSide& CSide::operator=(const CSide& s)
 
 
 /*********************************************
- 
+
             Global functions
- 
+
  *********************************************/
 
 /** Outputs a CPanel  to a stream.
@@ -1276,7 +1285,7 @@ ostream& operator<<(ostream& o, const CPanel &p)
  */
 ostream& operator<< (ostream &o, const CPanelLabel &lb)
 {
-    o << "== CPanelLabel : name ==" << endl << lb.name << endl;
+    o << "== CPanelLabel : name ==" << endl << string(lb.name.toLocal8Bit()) << endl;
     o << "== CPanelLabel : height ==" << endl << lb.height << endl;
     o << "== CPanelLabel : color ==" << endl << lb.color << endl;
     o << "== CPanelLabel : origin ==" << endl << lb.origin << endl;
