@@ -1,8 +1,8 @@
 /*
- * Copyright (C) 1993-2004 Robert & Jeremy Lain
+ * Copyright (C) 1993-2005 Robert & Jeremy Lain
  * See AUTHORS file for a full list of contributors.
  *
- * $Id: saildoc.cpp,v 1.52 2005/03/13 18:23:29 sailcuter Exp $
+ * $Id: saildoc.cpp,v 1.54 2005/09/03 14:28:58 jeremy_laine Exp $
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -20,9 +20,7 @@
  */
 
 #include "saildoc.h"
-#include <qfile.h>
-#include <qfiledialog.h>
-#include <qmessagebox.h>
+#include <QFile>
 
 
 /**************************************************************************
@@ -36,8 +34,6 @@
 CSailDoc::CSailDoc()
         : QDomDocument("Sailcut")
 {
-
-
     top = createElement("CSailDoc");
     appendChild(top);
 }
@@ -51,10 +47,9 @@ CSailDoc::CSailDoc( const QString &filename )
 {
     QFile f( filename );
 
-    if ( !f.open(IO_ReadOnly) )
+    if ( !f.open(QIODevice::ReadOnly) )
     {
         throw CException("CSailDoc::CSailDoc : cannot open file for read access!");
-        return;
     }
 
     if ( !setContent( &f ) )
@@ -108,7 +103,7 @@ QDomElement CSailDoc::findElement(const QDomNode &parent, const QString &type, c
     }
 
     // we didn't find the element, throw an exception
-    throw CException("CSailDoc::findElement(" + type + "," + name + ") : did not find requested element");
+    throw CException(QString("CSailDoc::findElement(" + type + "," + name + ") : did not find requested element").toLocal8Bit());
 
     n.clear();
     return n.toElement();
@@ -154,18 +149,6 @@ void CSailDoc::get
 }
 
 
-/** Reads a string value from an XML document.
- */
-void CSailDoc::get
-    ( const QDomNode &parent, string &s, const QString &name )
-{
-    QString temp;
-    get
-        (parent, temp, name);
-    s = temp.latin1();
-}
-
-
 /** Reads a CPoint3D from an XML document.
  */
 void CSailDoc::get
@@ -398,6 +381,8 @@ void CSailDoc::get
     ( const QDomNode &parent, CSail &s, const QString &name )
 {
     QDomElement e = findElement( parent, "CSail", name);
+    get
+        (e, s.sailID, "sailID");    
     get
         (e, s.panel, "panel");
 }
@@ -444,8 +429,6 @@ void CSailDoc::get
         (e, s.type, "type");
     get
         (e, s.filename, "filename");
-    get
-        (e, s.name, "name");
     get
         (e, s.origin, "origin");
 }
@@ -521,7 +504,7 @@ void CSailDoc::put( QDomNode &parent, const real &r, const QString &name )
 }
 
 
-/** Puts a string value to an XML document.
+/** Puts a QString string value to an XML document.
  */
 void CSailDoc::put( QDomNode &parent, const QString &s, const QString &name )
 {
@@ -530,14 +513,6 @@ void CSailDoc::put( QDomNode &parent, const QString &s, const QString &name )
 }
 
 
-/** Puts a string value to an XML document.
- */
-void CSailDoc::put( QDomNode &parent, const string &s, const QString &name )
-{
-    put(parent, QString(s.data()), name);
-}
-
-
 /** Puts a CPoint3d to an XML document.
  */
 void CSailDoc::put( QDomNode &parent, const CPoint3d &p, const QString &name )
@@ -679,7 +654,7 @@ void CSailDoc::put( QDomNode &parent, const CSailDef &d, const QString &name )
     put(e, d.mould, "mould");
 
     /* sail ID */
-    put(e, QString(d.sailID), "sailID" );
+    put(e, d.sailID, "sailID" );
 
     /* radial cut parameters */
     int temp=1;
@@ -739,6 +714,7 @@ void CSailDoc::put( QDomNode &parent, const CSail &s, const QString &name )
     QDomElement e = createElement("CSail",name);
     parent.appendChild(e);
 
+    put(e, s.sailID, "sailID");    
     put(e, s.panel, "panel");
 }
 
@@ -776,7 +752,6 @@ void CSailDoc::put( QDomNode &parent, const CRigSail &s, const QString &name )
 
     put(e, s.filename, "filename");
     put(e, s.type, "type");
-    put(e, s.name, "name");
     put(e, s.origin, "origin");
     put(e, (CSail&)s, "sail");
 }
@@ -819,12 +794,15 @@ void CSailDoc::put( QDomNode &parent, const CPrefs& p, const QString& name)
  */
 void CSailDoc::toFile(const QString &filename)
 {
-    FILE *fp = fopen(filename,"w");
+    QFile f( filename );
+    //FILE *fp = fopen(filename,"wb");
 
-    if ( !fp )
-        throw CException("CSailDoc::toFile : cannot open file for read access!");
-
-    fprintf(fp,toString());
-    fclose(fp);
+    if ( !f.open(QIODevice::WriteOnly) )
+    {
+        throw CException("CSailDoc::toFile : cannot open file for write access!");
+    }
+    
+    f.write(toByteArray());
+    f.close();
 }
 
