@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>Öffnen</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Speichern</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -7,14 +18,38 @@
     </message>
     <message>
         <source>There was an error writing to the selected file.</source>
-        <translation>Beim Schreiben in die gewÃ¤hlte Datei ist ein Fehler aufgetreten.</translation>
+        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten.</translation>
     </message>
 </context>
 <context>
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation>Eckpunktkoordinaten des Segels</translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation>Segelhals</translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation>Schothorn</translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation>Kopf</translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation>Nock</translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation>IRC - Breite</translation>
     </message>
 </context>
 <context>
@@ -201,23 +236,23 @@
     </message>
     <message>
         <source>Sheeting angle</source>
-        <translation type="unfinished"></translation>
+        <translation>Winkel der Segelbahn</translation>
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m²</translation>
+        <translation type="obsolete">m²</translation>
     </message>
     <message>
         <source>Sail area</source>
-        <translation type="unfinished"></translation>
+        <translation>Segelfläche</translation>
     </message>
     <message>
         <source>Diagonal</source>
-        <translation type="unfinished"></translation>
+        <translation>Diagonale</translation>
     </message>
     <message>
         <source>Compute</source>
-        <translation type="unfinished"></translation>
+        <translation>Berechnen</translation>
     </message>
     <message>
         <source>Sail ID </source>
@@ -225,19 +260,23 @@
     </message>
     <message>
         <source>Number of luff gores</source>
-        <translation type="unfinished"></translation>
+        <translation>Anzahl der Radialkeile beginnend am Kopf und endend am Segelhals</translation>
     </message>
     <message>
         <source>Dihedral angle</source>
-        <translation type="unfinished"></translation>
+        <translation>Öffnungswinkel</translation>
     </message>
     <message>
         <source>Wing</source>
-        <translation type="unfinished"></translation>
+        <translation>Tragfläche</translation>
     </message>
     <message>
         <source>Sail identifier</source>
-        <translation type="unfinished"></translation>
+        <translation>Segelnummer</translation>
+    </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
     </message>
 </context>
 <context>
@@ -335,87 +374,79 @@
     </message>
     <message>
         <source>Open &amp;recent</source>
-        <translation type="unfinished"></translation>
+        <translation>zuletzt geöffnete P&amp;rojekte</translation>
     </message>
     <message>
         <source>E&amp;xport 3D sail</source>
-        <translation type="unfinished"></translation>
+        <translation>E&amp;xport 3D-Segel</translation>
     </message>
     <message>
         <source>to &amp;Carlson plotter</source>
         <translation>&amp;Carlson Plotter</translation>
     </message>
-    <message>
-        <source>Export &amp;development</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Sailcut &amp;Handbook</source>
         <translation>Sailcut-&amp;Handbuch</translation>
     </message>
     <message>
         <source>shaded view</source>
-        <translation type="unfinished"></translation>
+        <translation>schattierte Ansicht</translation>
     </message>
     <message>
         <source>wireframe view</source>
-        <translation type="unfinished"></translation>
+        <translation>Ansicht als Drahtmodell</translation>
     </message>
     <message>
         <source>development</source>
-        <translation type="unfinished"></translation>
+        <translation>Entwicklung</translation>
     </message>
     <message>
         <source>created new sail</source>
-        <translation type="unfinished"></translation>
+        <translation>neu erstelltes Segel</translation>
     </message>
     <message>
         <source>loaded &apos;%1&apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>geladen &apos;%1&apos;</translation>
     </message>
     <message>
         <source>error loading &apos;%1&apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Laden von &apos;%1&apos; </translation>
     </message>
     <message>
         <source>wrote &apos;%1&apos;</source>
-        <translation type="unfinished"></translation>
+        <translation>gespeichert &apos;%1&apos;</translation>
     </message>
     <message>
         <source>There was a data printing error</source>
-        <translation type="unfinished">Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
+        <translation>Beim Schreiben in die gewählte Datei ist ein Fehler aufgetreten</translation>
     </message>
     <message>
         <source>There was a development printing error</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim Drucken der Entwicklungsansicht</translation>
     </message>
     <message>
         <source>There was a drawing printing error</source>
-        <translation type="unfinished"></translation>
+        <translation>Fehler beim drucken der Zeichnung</translation>
     </message>
     <message>
         <source>data</source>
-        <translation type="unfinished"></translation>
+        <translation>Daten</translation>
     </message>
     <message>
         <source>drawing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>develop</source>
-        <translation type="unfinished"></translation>
+        <translation>Zeichnung</translation>
     </message>
     <message>
         <source>&amp;Print</source>
-        <translation type="unfinished"></translation>
+        <translation>Dr&amp;ucken</translation>
     </message>
     <message>
         <source>Sailcut data sheet</source>
-        <translation type="unfinished"></translation>
+        <translation>Sailcut - Datenblatt</translation>
     </message>
     <message>
         <source>Sail type</source>
-        <translation type="unfinished"></translation>
+        <translation>Segeltyp</translation>
     </message>
     <message>
         <source>Mainsail</source>
@@ -475,7 +506,7 @@
     </message>
     <message>
         <source>Tack position X</source>
-        <translation type="unfinished"></translation>
+        <translation>Segelhalsposition X</translation>
     </message>
     <message>
         <source>Tack height Y</source>
@@ -527,23 +558,23 @@
     </message>
     <message>
         <source>Luff round position</source>
-        <translation type="unfinished"></translation>
+        <translation>Position des Vorliekbogens</translation>
     </message>
     <message>
         <source>Gaff round position</source>
-        <translation type="unfinished"></translation>
+        <translation>Position des Gaffelbogens</translation>
     </message>
     <message>
         <source>Leech round position</source>
-        <translation type="unfinished"></translation>
+        <translation>Position des Achterliekbogens</translation>
     </message>
     <message>
         <source>Foot round position</source>
-        <translation type="unfinished"></translation>
+        <translation>Position des Unterliekbogens</translation>
     </message>
     <message>
         <source>Sail settings</source>
-        <translation type="unfinished"></translation>
+        <translation>Eigenschaften des Segels</translation>
     </message>
     <message>
         <source>Twist angle</source>
@@ -551,11 +582,11 @@
     </message>
     <message>
         <source>Sheeting angle</source>
-        <translation type="unfinished"></translation>
+        <translation>Winkel der Segelbahn</translation>
     </message>
     <message>
         <source>Cloth seams and hems</source>
-        <translation type="unfinished"></translation>
+        <translation>Bahnennähte und Säume</translation>
     </message>
     <message>
         <source>Cloth width</source>
@@ -567,11 +598,11 @@
     </message>
     <message>
         <source>Leech hem width</source>
-        <translation type="unfinished"></translation>
+        <translation>Breite des Achterlieksaumes</translation>
     </message>
     <message>
         <source>Other hem width</source>
-        <translation type="unfinished"></translation>
+        <translation>andere Saumbreiten</translation>
     </message>
     <message>
         <source>Sail mould</source>
@@ -579,7 +610,7 @@
     </message>
     <message>
         <source>Luff factor</source>
-        <translation type="unfinished"></translation>
+        <translation>Vorliegsfaktor</translation>
     </message>
     <message>
         <source>Depth</source>
@@ -587,7 +618,7 @@
     </message>
     <message>
         <source>Leech factor</source>
-        <translation type="unfinished"></translation>
+        <translation>Achterlieksfaktor</translation>
     </message>
     <message>
         <source>Top profile</source>
@@ -595,7 +626,7 @@
     </message>
     <message>
         <source>Mid profile at h = </source>
-        <translation type="unfinished"></translation>
+        <translation>Mittleres Profil bei Höhe h =</translation>
     </message>
     <message>
         <source>Bottom profile</source>
@@ -607,15 +638,27 @@
     </message>
     <message>
         <source> head gores,   </source>
-        <translation type="unfinished"></translation>
+        <translation>Radialkeile im Kopfabschnitt </translation>
     </message>
     <message>
         <source>Wing</source>
-        <translation type="unfinished"></translation>
+        <translation>Tragfläche</translation>
     </message>
     <message>
         <source> luff gores.</source>
-        <translation type="unfinished"></translation>
+        <translation>Radialkeile beginnend am Kopf und endend am Segelhals.</translation>
+    </message>
+    <message>
+        <source>deg</source>
+        <translation>°</translation>
+    </message>
+    <message>
+        <source>Export &amp;development</source>
+        <translation>Export &amp;Entwicklung</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation>ins &amp;Hand-Plotterformat </translation>
     </message>
 </context>
 <context>
@@ -657,7 +700,7 @@
     <name>CFormRig</name>
     <message>
         <source>Rig</source>
-        <translation type="unfinished"></translation>
+        <translation>Rigg </translation>
     </message>
     <message>
         <source>&amp;New</source>
@@ -665,15 +708,15 @@
     </message>
     <message>
         <source>sail &amp;definition</source>
-        <translation type="unfinished"></translation>
+        <translation>&amp;Definition des Segels</translation>
     </message>
     <message>
         <source>3D &amp;sail</source>
-        <translation type="unfinished"></translation>
+        <translation>3D &amp;Segel</translation>
     </message>
     <message>
         <source>&amp;Add sail</source>
-        <translation type="unfinished"></translation>
+        <translation>neues Segel &amp;hinzufügen</translation>
     </message>
     <message>
         <source>&amp;Open</source>
@@ -681,7 +724,7 @@
     </message>
     <message>
         <source>Open &amp;recent</source>
-        <translation type="unfinished"></translation>
+        <translation>zuletzt geöffnete P&amp;rojekte</translation>
     </message>
     <message>
         <source>&amp;Save</source>
@@ -720,19 +763,19 @@
     </message>
     <message>
         <source>name</source>
-        <translation type="unfinished"></translation>
+        <translation>Bezeichnung</translation>
     </message>
     <message>
         <source>Reload</source>
-        <translation type="unfinished"></translation>
+        <translation>neu laden</translation>
     </message>
     <message>
         <source>Remove</source>
-        <translation type="unfinished"></translation>
+        <translation>Entfernen</translation>
     </message>
     <message>
         <source>Update</source>
-        <translation type="unfinished"></translation>
+        <translation>Aktualisieren</translation>
     </message>
     <message>
         <source>error</source>
@@ -747,7 +790,7 @@
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>Dieses System hat keine OpenGL Unterstützung.</translation>
+        <translation type="obsolete">Dieses System hat keine OpenGL Unterstützung.</translation>
     </message>
 </context>
 <context>
