@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>Åben</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Gem</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -113,7 +148,7 @@
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m² </translation>
+        <translation type="obsolete">m² </translation>
     </message>
     <message>
         <source>Compute</source>
@@ -240,6 +275,10 @@ stævn</translation>
         <source>Sail identifier</source>
         <translation>Sejl identifikation</translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -272,7 +311,7 @@ stævn</translation>
     </message>
     <message>
         <source>develop</source>
-        <translation>design</translation>
+        <translation type="obsolete">design</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -308,7 +347,7 @@ stævn</translation>
     </message>
     <message>
         <source>Export &amp;development</source>
-        <translation>Eksporter &amp;design sæt</translation>
+        <translation type="unfinished">Eksporter &amp;design sæt</translation>
     </message>
     <message>
         <source>&amp;Quit</source>
@@ -622,6 +661,14 @@ stævn</translation>
         <source> luff gores.</source>
         <translation>forli kiler.</translation>
     </message>
+    <message>
+        <source>deg</source>
+        <translation>grd</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -752,7 +799,7 @@ stævn</translation>
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>Dette system understøtter ikke OpenGL.</translation>
+        <translation type="obsolete">Dette system understøtter ikke OpenGL.</translation>
     </message>
 </context>
 <context>
