@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -91,10 +126,6 @@
         <source>deg</source>
         <translation type="unfinished"></translation>
     </message>
-    <message encoding="UTF-8">
-        <source>m²</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Gaff round</source>
         <translation type="unfinished"></translation>
@@ -239,6 +270,10 @@
         <source>Sail identifier</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -289,10 +324,6 @@
         <source>to &amp;Carlson plotter</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Export &amp;development</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Quit</source>
         <translation type="unfinished"></translation>
@@ -401,10 +432,6 @@
         <source>drawing</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>develop</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>&amp;Print</source>
         <translation type="unfinished"></translation>
@@ -617,6 +644,18 @@
         <source> luff gores.</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>deg</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Export &amp;development</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -743,13 +782,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>CSailDispGL</name>
-    <message>
-        <source>This system has no OpenGL support.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>CSailViewerPanel</name>
     <message>
