@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>Ouvrir</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Enregistrer</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation>Coordonnées des coins de la voile</translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation>amure</translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation>écoute</translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation>tête</translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation>pic</translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation>Largeurs mesurées IRC</translation>
     </message>
 </context>
 <context>
@@ -205,7 +240,7 @@
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m²</translation>
+        <translation type="obsolete">m²</translation>
     </message>
     <message>
         <source>Sail area</source>
@@ -239,6 +274,10 @@
         <source>Sail identifier</source>
         <translation>Identifiant de la voile</translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -399,7 +438,7 @@
     </message>
     <message>
         <source>develop</source>
-        <translation>développement</translation>
+        <translation type="obsolete">développement</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -629,6 +668,22 @@
         <source> luff gores.</source>
         <translation>fuseaux de guindant.</translation>
     </message>
+    <message>
+        <source>E&amp;xport &amp;development</source>
+        <translation type="obsolete">E&amp;xport développement</translation>
+    </message>
+    <message>
+        <source>to &amp;hand-plotting format</source>
+        <translation type="obsolete">format coupe &amp;manuelle</translation>
+    </message>
+    <message>
+        <source>deg</source>
+        <translation>deg</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation>pour traçage &amp;manuel</translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -759,7 +814,7 @@
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>OpenGL n&apos;est pas disponible sur cette machine.</translation>
+        <translation type="obsolete">OpenGL n&apos;est pas disponible sur cette machine.</translation>
     </message>
 </context>
 <context>
