@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>Openen</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Opslaan</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message encoding="UTF-8">
+        <source>Sail corners coordinates</source>
+        <translation>Zeilhoek coördinaten</translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation>halshoek</translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation>halshoek</translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation>tophoek</translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation>tophoek</translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation>IRC breedtematen</translation>
     </message>
 </context>
 <context>
@@ -81,7 +116,7 @@
     </message>
     <message>
         <source>Rig geometry</source>
-        <translation>Tuigage afmetingen</translation>
+        <translation>Tuigage geometrie</translation>
     </message>
     <message>
         <source>Fore triangle base  J</source>
@@ -205,7 +240,7 @@
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m²</translation>
+        <translation type="obsolete">m²</translation>
     </message>
     <message>
         <source>Sail area</source>
@@ -239,6 +274,10 @@
         <source>Sail identifier</source>
         <translation>Zeil ID</translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -267,7 +306,7 @@
     </message>
     <message>
         <source>to &amp;DXF</source>
-        <translation>naar &amp;DXF zeil</translation>
+        <translation>naar &amp;DXF</translation>
     </message>
     <message>
         <source>to &amp;TXT sail</source>
@@ -365,7 +404,7 @@
         <source>development</source>
         <translation>banen</translation>
     </message>
-    <message>
+    <message encoding="UTF-8">
         <source>created new sail</source>
         <translation>nieuw zeil gecreëerd</translation>
     </message>
@@ -403,7 +442,7 @@
     </message>
     <message>
         <source>develop</source>
-        <translation>banen</translation>
+        <translation type="obsolete">banen</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -559,7 +598,7 @@
     </message>
     <message>
         <source>Sheeting angle</source>
-        <translation>Schoothoek</translation>
+        <translation>Schootlijn hoek</translation>
     </message>
     <message>
         <source>Cloth seams and hems</source>
@@ -575,7 +614,7 @@
     </message>
     <message>
         <source>Leech hem width</source>
-        <translation>Achterlijk zoom</translation>
+        <translation>Achterlijk zoom breedte</translation>
     </message>
     <message>
         <source>Other hem width</source>
@@ -615,11 +654,11 @@
     </message>
     <message>
         <source> head gores,   </source>
-        <translation>hoofd banen,   </translation>
+        <translation> hoofd banen,   </translation>
     </message>
     <message>
         <source> luff gore.</source>
-        <translation type="obsolete">voorlijk banen.</translation>
+        <translation type="obsolete"> voorlijk baan.</translation>
     </message>
     <message>
         <source>Wing</source>
@@ -629,6 +668,14 @@
         <source> luff gores.</source>
         <translation> voorlijk banen.</translation>
     </message>
+    <message>
+        <source>deg</source>
+        <translation>gr</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation>naar &amp;Handmatige plotgegevens</translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -759,7 +806,7 @@
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>Dit systeem ondersteunt geen OpenGL.</translation>
+        <translation type="obsolete">Dit systeem ondersteunt geen OpenGL.</translation>
     </message>
 </context>
 <context>
