@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>åpne</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Lagre</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 <context>
@@ -205,7 +240,7 @@
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m²</translation>
+        <translation type="obsolete">m²</translation>
     </message>
     <message>
         <source>Sail area</source>
@@ -239,6 +274,10 @@
         <source>Sail identifier</source>
         <translation>Seil ID</translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -403,7 +442,7 @@
     </message>
     <message>
         <source>develop</source>
-        <translation>lag paneler</translation>
+        <translation type="obsolete">lag paneler</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -621,6 +660,14 @@
         <source> luff gores.</source>
         <translation>baner i forlik.</translation>
     </message>
+    <message>
+        <source>deg</source>
+        <translation>grad</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -751,7 +798,7 @@
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>OpenGL er ikke tilgjengelig.</translation>
+        <translation type="obsolete">OpenGL er ikke tilgjengelig.</translation>
     </message>
 </context>
 <context>
