@@ -1,4 +1,15 @@
 <!DOCTYPE TS><TS>
+<context>
+    <name>CFileIO</name>
+    <message>
+        <source>Open</source>
+        <translation>Abrir</translation>
+    </message>
+    <message>
+        <source>Save</source>
+        <translation>Salvar</translation>
+    </message>
+</context>
 <context>
     <name>CFileWriter</name>
     <message>
@@ -14,7 +25,31 @@
     <name>CFormDef</name>
     <message>
         <source>Sailcut</source>
-        <translation>Sailcut</translation>
+        <translation type="obsolete">Sailcut</translation>
+    </message>
+    <message>
+        <source>Sail corners coordinates</source>
+        <translation type="unfinished">Coordenadas dos punhos da vela</translation>
+    </message>
+    <message>
+        <source>tack</source>
+        <translation type="unfinished">amura</translation>
+    </message>
+    <message>
+        <source>clew</source>
+        <translation type="unfinished">escota</translation>
+    </message>
+    <message>
+        <source>head</source>
+        <translation type="unfinished">gurutil</translation>
+    </message>
+    <message>
+        <source>peak</source>
+        <translation type="unfinished">pena</translation>
+    </message>
+    <message>
+        <source>IRC width measurements</source>
+        <translation type="unfinished">Larguras IRC</translation>
     </message>
 </context>
 <context>
@@ -113,7 +148,7 @@
     </message>
     <message encoding="UTF-8">
         <source>m²</source>
-        <translation>m²</translation>
+        <translation type="obsolete">m²</translation>
     </message>
     <message>
         <source>Compute</source>
@@ -225,7 +260,7 @@
     </message>
     <message>
         <source>Number of luff gores</source>
-        <translation>Numero de radiais da testa</translation>
+        <translation>Número de radiais da testa</translation>
     </message>
     <message>
         <source>Dihedral angle</source>
@@ -239,6 +274,10 @@
         <source>Sail identifier</source>
         <translation>Identificação da vela</translation>
     </message>
+    <message>
+        <source>m2</source>
+        <translation>m2</translation>
+    </message>
 </context>
 <context>
     <name>CFormHelp</name>
@@ -271,7 +310,7 @@
     </message>
     <message>
         <source>develop</source>
-        <translation>desenvolvimento</translation>
+        <translation type="obsolete">desenvolvimento</translation>
     </message>
     <message>
         <source>&amp;Print</source>
@@ -359,11 +398,11 @@
     </message>
     <message>
         <source>shaded view</source>
-        <translation>Vista sombreada 3D</translation>
+        <translation>Vista sombreada</translation>
     </message>
     <message>
         <source>wireframe view</source>
-        <translation>vista em grelha 3D</translation>
+        <translation>vista em grelha</translation>
     </message>
     <message>
         <source>development</source>
@@ -625,6 +664,14 @@
         <source> luff gores.</source>
         <translation>Radiais da testa.</translation>
     </message>
+    <message>
+        <source>deg</source>
+        <translation>graus</translation>
+    </message>
+    <message>
+        <source>to &amp;Hand-plotting format</source>
+        <translation type="unfinished">para formato de Traçar à &amp;mão</translation>
+    </message>
 </context>
 <context>
     <name>CFormMould</name>
@@ -748,14 +795,14 @@
     </message>
     <message>
         <source>There was an error reading from the selected file.</source>
-        <translation>Houve um erro ao ler do ficheiro seleccionado</translation>
+        <translation>Houve um erro ao ler do ficheiro seleccionado.</translation>
     </message>
 </context>
 <context>
     <name>CSailDispGL</name>
     <message>
         <source>This system has no OpenGL support.</source>
-        <translation>Este sistema não tem suporte OpenGL</translation>
+        <translation type="obsolete">Este sistema não tem suporte OpenGL</translation>
     </message>
 </context>
 <context>
@@ -824,7 +871,7 @@
     </message>
     <message>
         <source>There was an error reading from the selected file.</source>
-        <translation>Houve um erro ao ler do ficheiro seleccionado.</translation>
+        <translation type="unfinished">Houve um erro ao ler do ficheiro seleccionado.</translation>
     </message>
 </context>
 </TS>
